Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(374)

Unified Diff: chrome/test/automation/automation_messages_internal.h

Issue 4194007: Revert "Refactor automation messages." due to mysterious problems on mac. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 10 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/test/automation/automation_messages.cc ('k') | chrome/test/automation/automation_proxy.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/test/automation/automation_messages_internal.h
diff --git a/chrome/common/automation_messages_internal.h b/chrome/test/automation/automation_messages_internal.h
similarity index 99%
rename from chrome/common/automation_messages_internal.h
rename to chrome/test/automation/automation_messages_internal.h
index ab3c97c4908b921c4a4a0c2cc72aaf012662f3ef..adadf68183f1dffcef91ce12ae44b5f04e1fd378 100644
--- a/chrome/common/automation_messages_internal.h
+++ b/chrome/test/automation/automation_messages_internal.h
@@ -611,8 +611,9 @@ IPC_BEGIN_MESSAGES(Automation)
// - int: handle of the tab
// Response:
// - bool: whether the operation was successful.
- // - PageType: the type of the page currently displayed.
- IPC_SYNC_MESSAGE_ROUTED1_2(AutomationMsg_GetPageType, int, bool, PageType)
+ // - NavigationEntry::PageType: the type of the page currently displayed.
+ IPC_SYNC_MESSAGE_ROUTED1_2(AutomationMsg_GetPageType, int, bool,
+ NavigationEntry::PageType)
// This message simulates the user action on the SSL blocking page showing in
// the specified tab. This message is only effective if an interstitial page
@@ -951,7 +952,7 @@ IPC_BEGIN_MESSAGES(Automation)
int /* tab_handle */,
HANDLE /* source menu handle */,
int /* align flags */,
- IPC::MiniContextMenuParams /* params */)
+ IPC::ContextMenuParams /* params */)
IPC_MESSAGE_ROUTED2(AutomationMsg_ForwardContextMenuCommandToChrome,
int /* tab_handle */,
« no previous file with comments | « chrome/test/automation/automation_messages.cc ('k') | chrome/test/automation/automation_proxy.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698